Documentation
¶
Index ¶
- Constants
- func Divide(a float64, b int) float64
- func DivideFloat(a, b float64) float64
- func DivideTimesRate(a, b, rate float64) float64
- func Euro(a, rate float64) float64
- func Half(a float64) float64
- func Kenmerk(now time.Time) string
- func TeXFiles(dir string) ([]string, error)
- type Conform
- type ConformMail
Constants ¶
const Template = "conform.tex.tmpl"
Variables ¶
This section is empty.
Functions ¶
func DivideFloat ¶
func DivideTimesRate ¶
Types ¶
type Conform ¶
type Conform struct {
FileName string // Name of the generated PDF.
Kenmerk string // Unique kenmerk of this invoice.
Tour string
Persons int
Time string
Duration string // 2:00
Cost float64
Rate float64 // current GBP:EUR rate, autofill
Date string // YYYY/MM/DD form
Name string
FullName string
Email string // Has become optional.
Where string // Where to pickup.
How string // Ends in "om".
Day string // autofill
}
Conform holds all the data we need to generate a conform
func (*Conform) Create ¶
Create parses the templates and runs pdflatex on the resulting tex file. It returns generated PDF.
func (*Conform) ExecuteTemplateAndWrite ¶
ExecuteTemplateAndWrite executes the template and writes the buffer to dst.
func (*Conform) FillOut ¶
FillOut fills in these missing fields in i, such as: Day, Filename and makes Date Dutch.
func (*Conform) MailSubject ¶
type ConformMail ¶
ConformMail is a customer conform form.
Click to show internal directories.
Click to hide internal directories.